pub struct AttachmentMetadata {
pub id: u64,
pub filename: String,
pub description: Option<String>,
}Expand description
Attachment metadata entry for the attachments field of MessageCreatePayload.
id must match the index used in the corresponding files[N] multipart part.
Fields
id: u64filename: Stringdescription: Option<String>Trait Implementations
Sourceimpl Clone for AttachmentMetadata
impl Clone for AttachmentMetadata
Sourcefn clone(&self) -> AttachmentMetadata
fn clone(&self) -> AttachmentMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AttachmentMetadata
impl Debug for AttachmentMetadata